@@ -21,7 +21,9 @@ def get_meta_value(
         if len(meta):
             try:
                 value = int(meta["value"])
-            except KeyError:
+            except (KeyError, ValueError):
+                # apparently for on/off services, this is
+                # now the service name
                 value = None
 
             try:
