@@ -97,14 +97,33 @@ class ExtensionBigTable(BigTable):
 
     @staticmethod
     def _complement(key: str, length: int):
+        """
+        pad the key with zeros to the specified length
+        :param key: the key to complement
+        :param length: the full length
+        :return: padded string with zeros of the specified length
+        """
         return key.rjust(length, '0')
 
     @staticmethod
     def _reverse(key: str):
+        """
+        reverse key characters, e.g. 12345 becomes 54321
+        :param key: the key to reverse
+        :return: reversed key
+        """
         return key[::-1]
 
     @staticmethod
     def _long_key_formatter(key):
+        """
+        format a key to 14 characters
+        the first character represent the number sign, 0 for negative, 1 for positive
+        the second part is a 36 radix representation of the key
+        then pad the concatenation of those two parts to 14 characters
+        :param key: the key to format
+        :return: formatted key
+        """
         length = 14
         return '0' + ExtensionBigTable._complement(ExtensionBigTable._to_string(sys.maxsize + key + 1, 36),
                                                    length - 1) if key < 0 else '1' + ExtensionBigTable._complement(
@@ -112,14 +131,33 @@ class ExtensionBigTable(BigTable):
 
     @staticmethod
     def _twisted_long_key_formatter(key):
+        """
+        reverse the result of `~qai.ExtensionBigTable._long_key_formatter`
+        :param key: the key to format
+        :return: formatted key
+        """
         return ExtensionBigTable._reverse(ExtensionBigTable._long_key_formatter(key))
 
     @staticmethod
     def _max_length_string_key_formatter(key: str, length: int = 100):
+        """
+        pad the specified key to the specified length
+        :param key: the key to pad
+        :param length: the length to pad to
+        :return: padded key to the specified length
+        """
         return ExtensionBigTable._complement(key, length)
 
     @staticmethod
     def _generate_key(document_id, organization_id, workspace_id, persona_id):
+        """
+        generate key for bigtable extension table, format agreed with extensions back-end
+        :param document_id: the document id
+        :param organization_id: the organization id
+        :param workspace_id: the workspace id
+        :param persona_id: the persona id
+        :return: formatted key
+        """
         return '|'.join([
             ExtensionBigTable._twisted_long_key_formatter(organization_id),
             ExtensionBigTable._twisted_long_key_formatter(workspace_id),
